SystemOrganization addCategory: #ConfigurationOfRoassal!

Object subclass: #ConfigurationOfRoassal
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfRoassal'!

!ConfigurationOfRoassal classSide methodsFor: 'development support' stamp: ''!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfRoassal classSide methodsFor: 'private' stamp: ''!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfRoassal classSide methodsFor: 'private' stamp: ''!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfRoassal classSide methodsFor: 'private' stamp: ''!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfRoassal classSide methodsFor: 'metacello tool support' stamp: ''!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfRoassal classSide methodsFor: 'loading' stamp: ''!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfRoassal classSide methodsFor: 'loading' stamp: ''!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfRoassal classSide methodsFor: 'loading' stamp: ''!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfRoassal classSide methodsFor: 'accessing' stamp: ''!
project

	^self new project! !

!ConfigurationOfRoassal classSide methodsFor: 'development support' stamp: ''!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: ''!
baseline10: spec
	<version: '0.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec group: 'default' with: #(#Roassal ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 4/18/2012 14:16'!
baseline11: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec package: 'Roassal-Morphic'.
		spec group: 'default' with: #(#Roassal ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 4/18/2012 15:17'!
baseline12: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec package: #RoassalMorphic.
		spec group: 'default' with: #(#Roassal #RoassalMorphic). ].
! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 10/30/2012 11:53'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.183'.
! !

!ConfigurationOfRoassal methodsFor: 'accessing' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 7/15/2012 13:55'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.61'.
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/28/2012 17:17'!
version0129: spec
	<version: '0.129' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.128 : Removed a platform dependent method
0.129 : An edge with a null extremity cannot be added in the builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/28/2012 17:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.141';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/30/2012 09:38'!
version0130: spec
	<version: '0.130' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.129 : An edge with a null extremity cannot be added in the builder
0.130 : Added method complexity example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/30/2012 09:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.143';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/30/2012 17:30'!
version0131: spec
	<version: '0.131' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.130 : Added method complexity example
0.131 : No popup and ViewStack that works well!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/30/2012 17:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.144';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 16:39'!
version0132: spec
	<version: '0.132' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.131 : No popup and ViewStack that works well!!
0.132 : Fixed bug with misplaced popup'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 16:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.145';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 17:33'!
version0133: spec
	<version: '0.133' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.132 : Fixed bug with misplaced popup
0.133 : Added command example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 17:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.146';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 17:43'!
version0134: spec
	<version: '0.134' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.133 : Added command example
0.134 : Added zoom. Try: ROMondrianExample new command'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 17:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 19:25'!
version0135: spec
	<version: '0.135' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.134 : Added zoom. Try: ROMondrianExample new command
0.135 : Added an easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 19:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.10'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 09:43'!
version0136: spec
	<version: '0.136' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.135 : Added an easel
0.136 : Added a zoom in and zoom out and find in the easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 09:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.11'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 10:41'!
version0137: spec
	<version: '0.137' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.136 : Added a zoom in and zoom out and find in the easel
0.137 : removed allPopups since it is not necessary and caused problem on VW (because of the WeakSet)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 10:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.148';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.12'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 10:51'!
version0138: spec
	<version: '0.138' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.137 : removed allPopups since it is not necessary and caused problem on VW (because of the WeakSet)
0.138 : Added a highlight when finding a node in the easel.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 10:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.148';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.13'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 09:56'!
version0139: spec
	<version: '0.139' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.138 : Added a highlight when finding a node in the easel.
0.139 : bug fixed with popupView:
0.139 : Worked on the examples and fixed what Vanessa asked for'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 09:56'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.150';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.14'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 16:47'!
version0140: spec
	<version: '0.140' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.139 : Worked on the examples and fixed what Vanessa asked for
0.140 : added a rotimeorganizer. Useful for the VW port'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 16:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.151';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.14'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 17:11'!
version0141: spec
	<version: '0.141' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.140 : added a rotimeorganizer. Useful for the VW port
0.141 : Move a class to the right package.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 17:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.152';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.15'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:24'!
version0142: spec
	<version: '0.142' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.141 : Move a class to the right package.
0.142 : Added RODummyNode, else Sugiyama does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.153';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.15'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:36'!
version0143: spec
	<version: '0.143' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.142 : Added RODummyNode, else Sugiyama does not work
0.143 : Added an example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.154';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.16'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:40'!
version0144: spec
	<version: '0.144' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.143 : Added an example
0.144 : minor fix in the sugiyama layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:40'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.155';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.16'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/4/2012 11:05'!
version0145: spec
	<version: '0.145' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.144 : minor fix in the sugiyama layout
0.145 : Worked on the tutorial. Added a ROSequenceInteraction'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/4/2012 11:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.156';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.17'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/4/2012 11:32'!
version0146: spec
	<version: '0.146' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.145 : Worked on the tutorial. Added a ROSequenceInteraction
0.146 : Fixed the tests for ROSequenceInteraction'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/4/2012 11:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.157';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.17'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/6/2012 10:35'!
version0147: spec
	<version: '0.147' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.146 : Fixed the tests for ROSequenceInteraction
0.147 : Bug fixed with clickToFocus'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/6/2012 10:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.158';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.18'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 09:36'!
version0148: spec
	<version: '0.148' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.147 : Bug fixed with clickToFocus
0.148 : Minor cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 09:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.159';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.18'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 12:20'!
version0149: spec
	<version: '0.149' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.148 : Minor cleaning
0.149 : Renamed RODecorator into ROShape. It makes sense since RODecorator is not really the implementation of the decorator pattern anyway. Thanks Doru!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 12:20'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.160';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.19'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 18:14'!
version0150: spec
	<version: '0.150' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.149 : Renamed RODecorator into ROShape. It makes sense since RODecorator is not really the implementation of the decorator pattern anyway. Thanks Doru!!
0.150 : remove a super initialize in ROEvent.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 18:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.161';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.19'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 18:39'!
version0151: spec
	<version: '0.151' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.150 : remove a super initialize in ROEvent.
0.151 : Removed some old ref to ROMorph'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 18:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.162';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.20'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/9/2012 16:48'!
version0152: spec
	<version: '0.152' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.151 : Removed some old ref to ROMorph
0.152 : fixed the tests for circle layout, a problem was due on VW because of the float rounding apparently.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/9/2012 16:48'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.163';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.20'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 10:02'!
version0153: spec
	<version: '0.153' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.152 : fixed the tests for circle layout, a problem was due on VW because of the float rounding apparently.
0.153 : added a test for the unsubcription: for the event. And moved a test that is platform specific'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 10:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.164';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.21'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 22:11'!
version0154: spec
	<version: '0.154' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.153 : added a test for the unsubcription: for the event. And moved a test that is platform specific
0.154 : speeded up the rendering by about 50% by avoiding unnecessary form'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 22:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.165';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.22'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 22:30'!
version0155: spec
	<version: '0.155' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.154 : speeded up the rendering by about 50% by avoiding unnecessary form
0.155 : Removed unnecessary comment'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 22:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.166';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.23'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 22:50'!
version0156: spec
	<version: '0.156' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.155 : Removed unnecessary comment
0.156 : changed a == for a =. VW complained about it'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 22:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.167';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.23'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/11/2012 10:13'!
version0157: spec
	<version: '0.157' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.156 : changed a == for a =. VW complained about it
0.157 :  Moved a benchmark into Pharo specific package'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/11/2012 10:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.168';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.24'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/11/2012 14:26'!
version0158: spec
	<version: '0.158' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.157 :  Moved a benchmark into Pharo specific package
0.158 : moved test from Roassal to MorphicSpecific'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/11/2012 14:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.170';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.26'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/13/2012 11:27'!
version0159: spec
	<version: '0.159' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.158 : moved test from Roassal to MorphicSpecific
0.159 : Expanded the tutorial'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/13/2012 11:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.173';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.28'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/15/2012 15:26'!
version0160: spec
	<version: '0.160' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.159 : Expanded the tutorial
0.160 : have used a moValue: instead of a roValue:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/15/2012 15:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.174';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.28'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/17/2012 09:10'!
version0161: spec
	<version: '0.161' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.160 : have used a moValue: instead of a roValue:
0.161 : Removed the dependency with BlockContext'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/17/2012 09:10'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.175';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.28'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/17/2012 21:06'!
version0162: spec
	<version: '0.162' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.161 : Removed the dependency with BlockContext
0.162 : add a new layout, fixed some small lint issues (thanks Stef), added more example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/17/2012 21:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.176';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.29'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/18/2012 10:05'!
version0163: spec
	<version: '0.163' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.162 : add a new layout, fixed some small lint issues (thanks Stef), added more example
0.163 : Added example for dynamic layout.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/18/2012 10:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.177';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.29'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/20/2012 19:22'!
version10: spec
	<version: '1.0' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.163 : Added example for dynamic layout.
1.0 : Fix in the choiceLayout example. Much nicer example.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/20/2012 19:22'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.178';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.31'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/21/2012 11:07'!
version1100: spec
	<version: '1.100' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.99 : Fixed Issue 136:	Roassal hover popup on edges
	http://code.google.com/p/moose-technology/issues/detail?id=826
1.100 : 
Fixed Issue 138:	Change the logo of ObjectProfile in Roassal Pharo
Fixed  Issue 137:	Integrating Dennis'' treeMapLayout in Roassal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2012 11:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.279';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/22/2012 19:58'!
version1101: spec
	<version: '1.101' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.100 : 
Fixed Issue 138:	Change the logo of ObjectProfile in Roassal Pharo
Fixed  Issue 137:	Integrating Dennis'' treeMapLayout in Roassal
1.101 : Issue 139:	Use of {} in some of the code'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/22/2012 19:58'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.280';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/23/2012 22:49'!
version1102: spec
	<version: '1.102' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.101 : Issue 139:	Use of {} in some of the code
1.102 : Fixes for VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/23/2012 22:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.281';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/23/2012 22:54'!
version1103: spec
	<version: '1.103' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.102 : Fixes for VW
1.103 : cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/23/2012 22:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.282';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/27/2012 10:06'!
version1104: spec
	<version: '1.104' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.103 : cleaning
1.104 : Fixed Issue 140:	TreeMap makes use of non existing methods in Pharo'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/27/2012 10:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.283';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/2/2012 00:38'!
version1105: spec
	<version: '1.105' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.104 : Fixed Issue 140:	TreeMap makes use of non existing methods in Pharo
1.105 : - all tests are green. Started to work on a menu widget.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/2/2012 00:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.285';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/2/2012 21:16'!
version1106: spec
	<version: '1.106' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.105 : - all tests are green. Started to work on a menu widget.
1.106 : Added ROAbstractElement>>on:doOnce: Useful for the menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/2/2012 21:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.286';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/4/2012 14:37'!
version1107: spec
	<version: '1.107' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.106 : Added ROAbstractElement>>on:doOnce: Useful for the menu
1.107 : small example for menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/4/2012 14:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.287';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/4/2012 15:31'!
version1108: spec
	<version: '1.108' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.107 : small example for menu
1.108 : Fixed Issue 141:	ROView>>add:
	Thanks Luc Fabresse and Noury Bouraqadi '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/4/2012 15:31'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.288';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/5/2012 10:23'!
version1109: spec
	<version: '1.109' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.108 : Fixed Issue 141:	ROView>>add:
	Thanks Luc Fabresse and Noury Bouraqadi 
1.109 : Fixed Issue 830:	ROLabel dynamic text not updating bounds/ROBorder properly 
	Fixed Issue 142:	ROLabel dynamic text not updating bounds/ROBorder properly'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/5/2012 10:23'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.289';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.68'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 14:04'!
version110: spec
	<version: '1.10' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.9 : Added a sortElementsWith: on ROAbstractView to reorder the nodes. Added a doPost: on ROLayout
1.10 : forgotten to implement doPost:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 14:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.187';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/9/2012 19:36'!
version1110: spec
	<version: '1.110' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.109 : Fixed Issue 830:	ROLabel dynamic text not updating bounds/ROBorder properly 
	Fixed Issue 142:	ROLabel dynamic text not updating bounds/ROBorder properly
1.110 : Doru''s fix for allElementsDo: and friends'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/9/2012 19:36'.
		spec 
			package: #Roassal with: 'Roassal-TudorGirba.292';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.68'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/9/2012 20:06'!
version1111: spec
	<version: '1.111' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.110 : Doru''s fix for allElementsDo: and friends
1.111 : Fixed Issue 148:	Roassal layouts do not properly take into account userDefinedEdges 
	http://code.google.com/p/moose-technology/issues/detail?id=834'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/9/2012 20:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.293';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.68'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/10/2012 10:02'!
version1112: spec
	<version: '1.112' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.111 : Fixed Issue 148:	Roassal layouts do not properly take into account userDefinedEdges 
	http://code.google.com/p/moose-technology/issues/detail?id=834
1.112 : Fixed Issue 149:	morph size. Thanks Doru for reporting the issue!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/10/2012 10:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.294';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.69'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/10/2012 10:12'!
version1113: spec
	<version: '1.113' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.112 : Fixed Issue 149:	morph size. Thanks Doru for reporting the issue!!
1.113 : added a new test for the bitmap size'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/10/2012 10:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.294';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.70'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/11/2012 09:05'!
version1114: spec
	<version: '1.114' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.113 : added a new test for the bitmap size
1.114 : Improvement of TreeMap. From Dennis Schenk: "This version includes more bugfixes and tests and an optimization: The layout doesn''t draw children of nodes if a certain minimum area per node is not available (the minimum area is configurable). This is for performance reasons.". Thanks a lot!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/11/2012 09:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.295';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.70'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/11/2012 16:03'!
version1115: spec
	<version: '1.115' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.114 : Improvement of TreeMap. From Dennis Schenk: "This version includes more bugfixes and tests and an optimization: The layout doesn''t draw children of nodes if a certain minimum area per node is not available (the minimum area is configurable). This is for performance reasons.". Thanks a lot!!
1.115 : Sync with VisualWorks'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/11/2012 16:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.296';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.71'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/11/2012 18:42'!
version1116: spec
	<version: '1.116' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.115 : Sync with VisualWorks
1.116 : Improvement of TreeMapLayout with the brightness.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/11/2012 18:42'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.297';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.71'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/14/2012 19:17'!
version1117: spec
	<version: '1.117' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.116 : Improvement of TreeMapLayout with the brightness.
1.117 : Fixed Issue 152:	Chaining the drawing of shapes '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/14/2012 19:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.298';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/15/2012 11:03'!
version1118: spec
	<version: '1.118' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.117 : Fixed Issue 152:	Chaining the drawing of shapes 
1.118 : Fixed Issue 153:	Shrinking element'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/15/2012 11:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.299';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/15/2012 22:47'!
version1119: spec
	<version: '1.119' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.118 : Fixed Issue 153:	Shrinking element
1.119 : Enhancement of the treemap layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/15/2012 22:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.300';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 17:54'!
version111: spec
	<version: '1.11' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.10 : forgotten to implement doPost:
1.11 : Added facilities to customize edge width'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 17:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.188';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/16/2012 12:52'!
version1120: spec
	<version: '1.120' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.119 : Enhancement of the treemap layout
1.120 : Fixed Issue 154:	resize strategy for shrinking. Thanks Ben for the suggestion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/16/2012 12:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.301';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/16/2012 14:20'!
version1121: spec
	<version: '1.121' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.120 : Fixed Issue 154:	resize strategy for shrinking. Thanks Ben for the suggestion
1.121 : Added TranslatingShape in the core
Fixed  Issue 155:	offset in a shape translation should be a block'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/16/2012 14:20'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.302';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 10:02'!
version1122: spec
	<version: '1.122' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.121 : Added TranslatingShape in the core
Fixed  Issue 155:	offset in a shape translation should be a block
1.122 : Fix from Dennis about the TreeMapLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 10:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.303';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 10:27'!
version1123: spec
	<version: '1.123' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.122 : Fix from Dennis about the TreeMapLayout
1.123 : Fixed  Issue 156:	ROPopup: Text not visible
	http://code.google.com/p/moose-technology/issues/detail?id=841'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 10:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.304';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 10:45'!
version1124: spec
	<version: '1.124' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.123 : Fixed  Issue 156:	ROPopup: Text not visible
	http://code.google.com/p/moose-technology/issues/detail?id=841
1.124 : Fixed Issue 157:	Duplication in ROAbstractArrow
http://code.google.com/p/objectprofile/issues/detail?id=157'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 10:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.305';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 12:14'!
version1125: spec
	<version: '1.125' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.124 : Fixed Issue 157:	Duplication in ROAbstractArrow
http://code.google.com/p/objectprofile/issues/detail?id=157
1.125 :
	Fixed Issue 158:	ROCenteredLabel 
	Fixed http://code.google.com/p/moose-technology/issues/detail?id=839'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 12:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.306';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 15:59'!
version1126: spec
	<version: '1.126' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.125 :
	Fixed Issue 158:	ROCenteredLabel 
	Fixed http://code.google.com/p/moose-technology/issues/detail?id=839
1.126 : minor fix'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 15:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.307';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/21/2012 14:03'!
version1127: spec
	<version: '1.127' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.126 : minor fix
1.127 : Issue 159:	ROMenuElement class>>example has a bad ref'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/21/2012 14:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.308';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/23/2012 12:55'!
version1128: spec
	<version: '1.128' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.127 : Issue 159:	ROMenuElement class>>example has a bad ref
1.128 : Fixed  Issue 160:	The treemap examples do not work in VW, because of with:with:with:with:with:with:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/23/2012 12:55'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.309';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/24/2012 11:17'!
version1129: spec
	<version: '1.129' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.128 : Fixed  Issue 160:	The treemap examples do not work in VW, because of with:with:with:with:with:with:
1.129 : Fixed Issue 163:	ROLightlyHighlightable drains element colour
	http://code.google.com/p/moose-technology/issues/detail?id=843
	Thanks Ben!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/24/2012 11:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.310';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 19:02'!
version112: spec
	<version: '1.12' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.11 : Added facilities to customize edge width
1.12 : fixed a bug with withText:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 19:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.189';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/24/2012 12:16'!
version1130: spec
	<version: '1.130' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.129 : Fixed Issue 163:	ROLightlyHighlightable drains element colour
	http://code.google.com/p/moose-technology/issues/detail?id=843
	Thanks Ben!!
1.130 : Fixed Issue 162:	Menu buttons are transparent. Best is to have them with a white background'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/24/2012 12:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.311';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 09:25'!
version1131: spec
	<version: '1.131' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.130 : Fixed Issue 162:	Menu buttons are transparent. Best is to have them with a white background
1.131 : Fixed Issue 164:	Children shape are not ending the chain shape anymore
	Fixed Issue 165:	Fix bug with the translate shape'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 09:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.312';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 11:19'!
version1132: spec
	<version: '1.132' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.131 : Fixed Issue 164:	Children shape are not ending the chain shape anymore
	Fixed Issue 165:	Fix bug with the translate shape
1.132 : Fixed Issue 166:	Non draggable view'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 11:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.313';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 19:13'!
version1133: spec
	<version: '1.133' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.132 : Fixed Issue 166:	Non draggable view
1.133 : Added a composite example in ROExample'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 19:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.314';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 19:45'!
version1134: spec
	<version: '1.134' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.133 : Added a composite example in ROExample
1.134 : Added a colroed system complexity in the mondrian example. Nice example of how to obtain color gradient.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 19:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.315';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 08:34'!
version1135: spec
	<version: '1.135' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.134 : Added a colroed system complexity in the mondrian example. Nice example of how to obtain color gradient.
1.135 : removed all work for the offset and translate shape'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 08:34'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.316';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 09:42'!
version1136: spec
	<version: '1.136' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.135 : removed all work for the offset and translate shape
1.136 : Fixed Issue 87:	method to rewrite'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 09:42'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.317';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 09:49'!
version1137: spec
	<version: '1.137' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.136 : Fixed Issue 87:	method to rewrite
1.137 : Fixed  Issue 126:	ROAbstractLine, ROLine'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 09:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.318';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 11:18'!
version1138: spec
	<version: '1.138' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.137 : Fixed  Issue 126:	ROAbstractLine, ROLine
1.138 : Cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 11:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.319';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 11:27'!
version1139: spec
	<version: '1.139' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.138 : Cleaning
1.139 : Fixed Issue 168:	linearFillColor:within: Mondrian builder does not operate with an empty list of elements'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 11:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.320';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 21:18'!
version113: spec
	<version: '1.13' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.12 : fixed a bug with withText:
1.13 : Removed unnecessary view classes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 21:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.190';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.36'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/29/2012 15:30'!
version1140: spec
	<version: '1.140' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.139 : Fixed Issue 168:	linearFillColor:within: Mondrian builder does not operate with an empty list of elements
1.140 : Fixed Issue 169:	Find button is not unlighted when clicking'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/29/2012 15:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.321';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/29/2012 16:22'!
version1141: spec
	<version: '1.141' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.140 : Fixed Issue 169:	Find button is not unlighted when clicking
1.141 : improved a test'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/29/2012 16:22'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.322';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 09:35'!
version1142: spec
	<version: '1.142' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.141 : improved a test
1.142 : Fixed Issue 170:	Adding constraints on elements'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 09:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.323';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 09:39'!
version1143: spec
	<version: '1.143' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.142 : Fixed Issue 170:	Adding constraints on elements
1.143 : Fixed Issue 171:	Need of dominance and horizontal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 09:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.325';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 09:45'!
version1144: spec
	<version: '1.144' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.143 : Fixed Issue 171:	Need of dominance and horizontal
1.144 : Fixed Issue 172:	Need for an example for layered horizontal tree layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 09:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.326';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 10:03'!
version1145: spec
	<version: '1.145' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.144 : Fixed Issue 172:	Need for an example for layered horizontal tree layout
1.145 : Fixed Issue 174:	Need to add an example for the constraints'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 10:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.327';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 13:50'!
version1146: spec
	<version: '1.146' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.145 : Fixed Issue 174:	Need to add an example for the constraints
1.146 : Fixed Issue 175:	Find does not work properly'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 13:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.328';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 09:35'!
version1147: spec
	<version: '1.147' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.146 : Fixed Issue 175:	Find does not work properly
1.147 : Sync with VisualWorks. Removed junk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 09:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.329';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 16:32'!
version1148: spec
	<version: '1.148' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.147 : Sync with VisualWorks. Removed junk
1.148 : Fixed Issue 176:	ROPopup need to be improved'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 16:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.330';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 16:38'!
version1149: spec
	<version: '1.149' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.148 : Fixed Issue 176:	ROPopup need to be improved
1.149 : Fix by Dennis Schenk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 16:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.331';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/28/2012 21:28'!
version114: spec
	<version: '1.14' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.13 : Removed unnecessary view classes
1.14 : Severe bug about the offset of the popup fixed.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/28/2012 21:28'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.191';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.37'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 19:58'!
version1150: spec
	<version: '1.150' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.149 : Fix by Dennis Schenk
1.150 : Fixed in Issue 177:	#attributes is not defined on ROAbstractElement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 19:58'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.332';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 20:34'!
version1151: spec
	<version: '1.151' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.150 : Fixed in Issue 177:	#attributes is not defined on ROAbstractElement
1.151 : Fixed Issue 178:	accessing the element (and not the model) from a menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 20:34'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.333';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 20:43'!
version1152: spec
	<version: '1.152' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.151 : Fixed Issue 178:	accessing the element (and not the model) from a menu
1.152 : Fixed Issue 179:	ROEdge>>elementFromModel: does not exist'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 20:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.334';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 09:06'!
version1153: spec
	<version: '1.153' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.152 : Fixed Issue 179:	ROEdge>>elementFromModel: does not exist
1.153 : 
	Fixed  Issue 180:	Bug in an example
	Fixed Issue 181:	Need some animation example in ROExample'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 09:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.335';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 16:29'!
version1154: spec
	<version: '1.154' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.153 : 
	Fixed  Issue 180:	Bug in an example
	Fixed Issue 181:	Need some animation example in ROExample
1.154 : Fixed Issue 182:	ROCircle border only'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 16:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.336';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 19:02'!
version1155: spec
	<version: '1.155' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.154 : Fixed Issue 182:	ROCircle border only
1.155 : Fixed Issue 183:	Need an easy way to add and remove elements'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 19:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.337';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 19:11'!
version1156: spec
	<version: '1.156' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.155 : Fixed Issue 183:	Need an easy way to add and remove elements
1.156 : Added example about status bar'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 19:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.338';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 19:15'!
version1157: spec
	<version: '1.157' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.156 : Added example about status bar
1.157 : Making the tests green'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 19:15'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.339';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/7/2012 13:11'!
version1158: spec
	<version: '1.158' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.157 : Making the tests green
1.158 : Fixed Issue 184:	Bug in the ExpandableNodesOn:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/7/2012 13:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.340';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/7/2012 13:59'!
version1159: spec
	<version: '1.159' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.158 : Fixed Issue 184:	Bug in the ExpandableNodesOn:
1.159 : Added a small example about nesting layout using Roassal Core'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/7/2012 13:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.341';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/28/2012 23:04'!
version115: spec
	<version: '1.15' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.14 : Severe bug about the offset of the popup fixed.
1.15 : added a ROStackViewWithMenu to easily build visualization with menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/28/2012 23:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.192';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.37'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/7/2012 17:11'!
version1160: spec
	<version: '1.160' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.159 : Added a small example about nesting layout using Roassal Core
1.160 : Minor fix in the method complexity'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/7/2012 17:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.341';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/8/2012 09:01'!
version1161: spec
	<version: '1.161' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.160 : Minor fix in the method complexity
1.161 : Fixed Issue 186:	RubbedBand from ben'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/8/2012 09:01'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.342';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/8/2012 09:38'!
version1162: spec
	<version: '1.162' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.161 : Fixed Issue 186:	RubbedBand from ben
1.162 : Cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/8/2012 09:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.343';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/9/2012 08:53'!
version1163: spec
	<version: '1.163' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.162 : Cleaning
1.163 :  Issue 187:	Offset for shorterattachpoint
	Added the offset from Dennis. Thanks!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/9/2012 08:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.344';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/11/2012 13:16'!
version1164: spec
	<version: '1.164' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.163 :  Issue 187:	Offset for shorterattachpoint
	Added the offset from Dennis. Thanks!!
1.164 : Fixed  Issue 188:	cleaning of interaction key'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/11/2012 13:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.345';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 10:18'!
version1165: spec
	<version: '1.165' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.164 : Fixed  Issue 188:	cleaning of interaction key
1.165 : Fixed  Issue 189:	Mondrian vs Roassal: a conceptual comparison
	Thanks Doru for spotting this problem'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 10:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.346';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 13:16'!
version1166: spec
	<version: '1.166' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.165 : Fixed  Issue 189:	Mondrian vs Roassal: a conceptual comparison
	Thanks Doru for spotting this problem
1.166 : Fixed Issue 190:	Example does not work in the easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 13:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.351';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 13:21'!
version1167: spec
	<version: '1.167' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.166 : Fixed Issue 190:	Example does not work in the easel
1.167 : comment in ROShape'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 13:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.352';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 20:17'!
version1168: spec
	<version: '1.168' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.167 : comment in ROShape
1.168 : Increased the tab conversion with a label.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 20:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.353';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 22:53'!
version1169: spec
	<version: '1.169' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.168 : Increased the tab conversion with a label.
1.169 : removing junk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 22:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.354';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/28/2012 23:35'!
version116: spec
	<version: '1.16' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.15 : added a ROStackViewWithMenu to easily build visualization with menu
1.16 : Removed a dependency to Pharo'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/28/2012 23:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.193';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.38'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/16/2012 14:19'!
version1170: spec
	<version: '1.170' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.169 : removing junk
1.170 : Small example from d3'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/16/2012 14:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.355';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/17/2012 08:35'!
version1171: spec
	<version: '1.171' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.170 : Small example from d3
1.171 :  Fixed Issue 192:	ROElement and ROAbstractElement. Thanks Doru for the suggestion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/17/2012 08:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.356';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/17/2012 14:04'!
version1172: spec
	<version: '1.172' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.171 :  Fixed Issue 192:	ROElement and ROAbstractElement. Thanks Doru for the suggestion
1.172 : Fixed Issue 193:	Mondrian vs Roassal: a conceptual comparison'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/17/2012 14:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.357';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/17/2012 14:11'!
version1173: spec
	<version: '1.173' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.172 : Fixed Issue 193:	Mondrian vs Roassal: a conceptual comparison
1.173 : cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/17/2012 14:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.358';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:16'!
version1174: spec
	<version: '1.174' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.173 : cleaning
1.174 : Issue 855:	Roassal Mondrian builder is not handling color based on the model
	
Issue 854:	Roassal Mondrian builder is not handling label based on model
Thanks Doru!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:16'.
		spec 
			package: #Roassal with: 'Roassal-TudorGirba.359';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:33'!
version1175: spec
	<version: '1.175' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.174 : Issue 855:	Roassal Mondrian builder is not handling color based on the model
	
Issue 854:	Roassal Mondrian builder is not handling label based on model
Thanks Doru!!
1.175 : minor changes in ROCenteredLabel>>drawOn:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.360';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:37'!
version1176: spec
	<version: '1.176' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.175 : minor changes in ROCenteredLabel>>drawOn:
1.176 : cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.361';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:50'!
version1177: spec
	<version: '1.177' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.176 : cleaning
1.177 : Fixed Issue 194:	testLogHeight and testLogWidth uses isFloat'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.362';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 18:17'!
version1178: spec
	<version: '1.178' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.177 : Fixed Issue 194:	testLogHeight and testLogWidth uses isFloat
1.178 : Fixed Issue 195:	ROAbstractElement>>remove inconsistent nested
	http://code.google.com/p/moose-technology/issues/detail?id=856
	Thanks Ben for having spotted it!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 18:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.363';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/20/2012 21:37'!
version1179: spec
	<version: '1.179' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.178 : Fixed Issue 195:	ROAbstractElement>>remove inconsistent nested
	http://code.google.com/p/moose-technology/issues/detail?id=856
	Thanks Ben for having spotted it!!
1.179 : Fixed Issue 197:	Circle do not compute the colors
	Fixed Issue 196:	Adding circle shape in the Mondrian builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/20/2012 21:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.364';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/29/2012 10:25'!
version117: spec
	<version: '1.17' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.16 : Removed a dependency to Pharo
1.17 : identified a bug with the label. Introduced the method preferedExtentsFor: Thanks Usman for finding it.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/29/2012 10:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.194';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.40'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/21/2012 11:44'!
version1180: spec
	<version: '1.180' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.179 : Fixed Issue 197:	Circle do not compute the colors
	Fixed Issue 196:	Adding circle shape in the Mondrian builder
1.180 : Cleaning ROMondrianBuilder. Removed two unused instance variables'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/21/2012 11:44'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.365';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/23/2012 09:02'!
version1181: spec
	<version: '1.181' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.180 : Cleaning ROMondrianBuilder. Removed two unused instance variables
1.181 : Fixed Issue 198:	borderWith: broken in Roassal?'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/23/2012 09:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.366';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/30/2012 11:52'!
version1182: spec
	<version: '1.182' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.181 : Fixed Issue 198:	borderWith: broken in Roassal?
1.182 : Fixed  Issue 199:	linearFillColor:within: does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/30/2012 11:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.367';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/30/2012 11:53'!
version1183: spec
	<version: '1.183' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.182 : Fixed  Issue 199:	linearFillColor:within: does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/30/2012 11:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.367';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/1/2012 10:29'!
version118: spec
	<version: '1.18' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.17 : identified a bug with the label. Introduced the method preferedExtentsFor: Thanks Usman for finding it.
1.18 : Fixed issue #64: 	Add a new attach point with shorter edge'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/1/2012 10:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.195';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.40'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/1/2012 15:06'!
version119: spec
	<version: '1.19' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.18 : Fixed issue #64: 	Add a new attach point with shorter edge
1.19 : Added ROButtonElement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/1/2012 15:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.196';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.40'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/20/2012 19:49'!
version11: spec
	<version: '1.1' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.0 : Fix in the choiceLayout example. Much nicer example.
1.1 : Minor fix in ROExample. A test has been moved to platform specific since it has a reference to PackagesInfo'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/20/2012 19:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.179';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.32'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/1/2012 18:07'!
version120: spec
	<version: '1.20' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.19 : Added ROButtonElement
1.20 : Added ROButtonElement and moved the Roassel easel in the Tools menu.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/1/2012 18:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.197';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.41'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 10:06'!
version121: spec
	<version: '1.21' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.20 : Added ROButtonElement and moved the Roassel easel in the Tools menu.
1.21 : Fixed ISSUE #61: Zooming in and out preserve the size of the popup. The zoom button can now be added to Hapao and Kai in VW. All tests are green'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 10:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.198';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 14:19'!
version122: spec
	<version: '1.22' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.21 : Fixed ISSUE #61: Zooming in and out preserve the size of the popup. The zoom button can now be added to Hapao and Kai in VW. All tests are green
1.22 : code cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 14:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.199';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 14:29'!
version123: spec
	<version: '1.23' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.22 : code cleaning
1.23 : Fixed Issue 50:	Variable rename in Roassal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 14:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.200';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 17:21'!
version124: spec
	<version: '1.24' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.23 : Fixed Issue 50:	Variable rename in Roassal
1.24 : Added a small accessor to stack in the builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 17:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.201';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 17:52'!
version125: spec
	<version: '1.25' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.24 : Added a small accessor to stack in the builder
1.25 : Bug in popupView:delay: fixed'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 17:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.202';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/3/2012 14:54'!
version126: spec
	<version: '1.26' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.25 : Bug in popupView:delay: fixed
1.26 :'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/3/2012 14:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.203';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/3/2012 15:25'!
version127: spec
	<version: '1.27' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.26 :
1.27 : Minor fix to make VW happy'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/3/2012 15:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.204';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/3/2012 15:45'!
version128: spec
	<version: '1.28' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.27 : Minor fix to make VW happy
1.28 : Fixe  Issue 21:	PopupView in ROMondrianViewBuilder in VW not working correctly'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/3/2012 15:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.205';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/4/2012 00:56'!
version129: spec
	<version: '1.29' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.28 : Fixe  Issue 21:	PopupView in ROMondrianViewBuilder in VW not working correctly
1.29 : Added blue color'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/4/2012 00:56'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.206';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/20/2012 23:25'!
version12: spec
	<version: '1.2' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.1 : Minor fix in ROExample. A test has been moved to platform specific since it has a reference to PackagesInfo
1.2 : Moved an example to PharoSpecific Example. The #image example caused an undeclared reference in VW.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/20/2012 23:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.180';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.33'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 10:06'!
version130: spec
	<version: '1.30' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.29 : Added blue color
1.30 : Pair programming with Dennis on graph transformation (going from edges-based to nesting-based)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 10:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.207';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 10:32'!
version131: spec
	<version: '1.31' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.30 : Pair programming with Dennis on graph transformation (going from edges-based to nesting-based)
1.31 : Added ROElement>>remove. Note that some of the tests are yellow. Checking the cycle is not finished yet. Working on that.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 10:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.208';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 10:47'!
version132: spec
	<version: '1.32' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.31 : Added ROElement>>remove. Note that some of the tests are yellow. Checking the cycle is not finished yet. Working on that.
1.32 : removed the nodes when we transform them. Pair programmed with Dennis'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 10:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.209';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 11:12'!
version133: spec
	<version: '1.33' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.32 : removed the nodes when we transform them. Pair programmed with Dennis
1.33 : Removed the failing tests'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 11:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.210';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 14:11'!
version134: spec
	<version: '1.34' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.33 : Removed the failing tests
1.34 : Attempt for the scrollbar. Redefined ROCamera>>height'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 14:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.211';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 23:24'!
version135: spec
	<version: '1.35' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.34 : Attempt for the scrollbar. Redefined ROCamera>>height
1.35 : Added an example with a scrollbar'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 23:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.212';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.44'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/11/2012 23:39'!
version136: spec
	<version: '1.36' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.35 : Added an example with a scrollbar
1.36 :
Issue 75:	ROLabelElement should be removed

Issue 76:	Rename ROMondrianViewBuilder>>container into raw

Issue 77: Announcer. ROView has a reference of Announcer, whereas it should refer ROAnnouncer instead.

Issue 78:	ROForceBaseLayout should be parametrizable
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/11/2012 23:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.213';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.45'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/13/2012 00:47'!
version137: spec
	<version: '1.37' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.36 :
Issue 75:	ROLabelElement should be removed

Issue 76:	Rename ROMondrianViewBuilder>>container into raw

Issue 77: Announcer. ROView has a reference of Announcer, whereas it should refer ROAnnouncer instead.

Issue 78:	ROForceBaseLayout should be parametrizable

1.37 : 
Fixed Issue 32:	Turn ROArrowedLine into a shape
Pair programmed with james Swaine during Dyla''12'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/13/2012 00:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.215';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/16/2012 00:52'!
version138: spec
	<version: '1.38' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.37 : 
Fixed Issue 32:	Turn ROArrowedLine into a shape
Pair programmed with james Swaine during Dyla''12
1.38 : ROElement>>remove does not raise an error anymore if the element is not part of a view. Thanks Dennis for suggesting this'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/16/2012 00:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.216';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 15:17'!
version139: spec
	<version: '1.39' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.38 : ROElement>>remove does not raise an error anymore if the element is not part of a view. Thanks Dennis for suggesting this
1.39 : Fixed Issue 79:	Cache and color
http://code.google.com/p/objectprofile/issues/detail?id=79

1.39 : element can now have attributes. Useful for the highlighting. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 15:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.218';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/21/2012 10:28'!
version13: spec
	<version: '1.3' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.2 : Moved an example to PharoSpecific Example. The #image example caused an undeclared reference in VW.
1.3 : Removed an unused method, findElementIn:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/21/2012 10:28'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.181';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.33'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 15:57'!
version140: spec
	<version: '1.40' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.39 : element can now have attributes. Useful for the highlighting. 
1.40 : - Added size for arrow. - added action to remove a node'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 15:57'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.219';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 16:04'!
version141: spec
	<version: '1.41' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.40 : - Added size for arrow. - added action to remove a node
1.41 : Moved the item in the world menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 16:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.219';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 20:52'!
version142: spec
	<version: '1.42' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.41 : Moved the item in the world menu
1.42 : Fix in the choose layout example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 20:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.220';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/19/2012 10:19'!
version143: spec
	<version: '1.43' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.42 : Fix in the choose layout example
1.43 : Example of latent semantic indexing '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/19/2012 10:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.221';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/24/2012 10:50'!
version144: spec
	<version: '1.44' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.43 : Example of latent semantic indexing 
1.44 : Making sure all the unit tests use ROTest. All the tests are green. Fixed Issue 80:	ROTest in Roassal
1.44 : Worked on the expandable nodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/24/2012 10:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.223';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/27/2012 09:51'!
version145: spec
	<version: '1.45' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.44 : Worked on the expandable nodes
1.45 : Patched ROGraphTransformation: It should also be possible that multiple rootNodes are found, not just on. Thanks Dennis!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/27/2012 09:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.224';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/30/2012 14:29'!
version146: spec
	<version: '1.46' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.45 : Patched ROGraphTransformation: It should also be possible that multiple rootNodes are found, not just on. Thanks Dennis!!
1.46 : Fixed Issue 85:	ROGridLayout and lineCounter. Thanks Usman!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/30/2012 14:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.225';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/2/2012 16:38'!
version147: spec
	<version: '1.47' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.46 : Fixed Issue 85:	ROGridLayout and lineCounter. Thanks Usman!!
1.47 : Normalizer added. New examples and tests have been added when migrating from Mondrian'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/2/2012 16:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.226';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/2/2012 17:14'!
version148: spec
	<version: '1.48' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.47 : Normalizer added. New examples and tests have been added when migrating from Mondrian
1.48 : Fixed Issue 88:	Color and edges'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/2/2012 17:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.227';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/3/2012 00:09'!
version149: spec
	<version: '1.49' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.48 : Fixed Issue 88:	Color and edges
1.49 : Making sure VW is happy when being loaded. a lot of {} were in the code of the normalizers'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/3/2012 00:09'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.228';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/21/2012 21:41'!
version14: spec
	<version: '1.4' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.3 : Removed an unused method, findElementIn:
1.4 :'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/21/2012 21:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.181';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.34'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/3/2012 13:51'!
version150: spec
	<version: '1.50' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.49 : Making sure VW is happy when being loaded. a lot of {} were in the code of the normalizers
1.50 : Fixed Issue 90:	if:popupText: in the builder would be useful'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/3/2012 13:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.229';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/3/2012 18:37'!
version151: spec
	<version: '1.51' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.50 : Fixed Issue 90:	if:popupText: in the builder would be useful
1.51 : Fixed a bug for the highlighting'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/3/2012 18:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.230';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 00:06'!
version152: spec
	<version: '1.52' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.51 : Fixed a bug for the highlighting
1.52 : All tests are green. Changed the superclass of the normalizer. Fixed  Issue 92:	Superclass of the normalizer
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 00:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.231';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 00:59'!
version153: spec
	<version: '1.53' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.52 : All tests are green. Changed the superclass of the normalizer. Fixed  Issue 92:	Superclass of the normalizer

1.53 : Making VW happy...'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 00:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.232';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 01:07'!
version154: spec
	<version: '1.54' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.53 : Making VW happy...
1.54 : Removed the last reference of SmallDictionary'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 01:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.233';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 16:37'!
version155: spec
	<version: '1.55' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.54 : Removed the last reference of SmallDictionary
1.55 : Fixed Issue 95:	Highlighting twice the same node'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 16:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.234';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/6/2012 13:02'!
version156: spec
	<version: '1.56' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.55 : Fixed Issue 95:	Highlighting twice the same node
1.56 : fixed a bug in Roassal with highlight'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/6/2012 13:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.235';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/7/2012 07:49'!
version157: spec
	<version: '1.57' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.56 : fixed a bug in Roassal with highlight
1.57 : Worked on the if:popupText:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/7/2012 07:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.236';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/7/2012 14:21'!
version158: spec
	<version: '1.58' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.57 : Worked on the if:popupText:
1.58 : minor fix'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/7/2012 14:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.237';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/9/2012 08:38'!
version159: spec
	<version: '1.59' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.58 : minor fix
1.59 : Fixed if:popupText: and fixed the tests for VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/9/2012 08:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.238';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/21/2012 22:13'!
version15: spec
	<version: '1.5' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.4 :
1.5 : Two popups cannot appear at the same time. http://code.google.com/p/objectprofile/issues/detail?id=48'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/21/2012 22:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.182';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/9/2012 10:17'!
version160: spec
	<version: '1.60' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.59 : Fixed if:popupText: and fixed the tests for VW
1.60 : minor fix for VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/9/2012 10:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.239';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/15/2012 13:33'!
version161: spec
	<version: '1.61' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.60 : minor fix for VW
1.61 :
  - fixed Issue 97:	Adding an interaction remove the popupText 
  - fixed Issue 98:	Border shape only takes color value
  - fixed Issue 99:	ROExample>>arrowedLine raises an error 
  - fixed Issue 100:	New step in the tutorial to conditionally color nodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/15/2012 13:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.240';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.49'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/16/2012 08:17'!
version162: spec
	<version: '1.62' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.61 :
  - fixed Issue 97:	Adding an interaction remove the popupText 
  - fixed Issue 98:	Border shape only takes color value
  - fixed Issue 99:	ROExample>>arrowedLine raises an error 
  - fixed Issue 100:	New step in the tutorial to conditionally color nodes
1.62 : Slightly Increased the coverage'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/16/2012 08:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.241';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/16/2012 20:37'!
version163: spec
	<version: '1.63' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.62 : Slightly Increased the coverage
1.63 : fixed some typos (which were found by VW) '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/16/2012 20:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.242';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/20/2012 18:18'!
version164: spec
	<version: '1.64' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.63 : fixed some typos (which were found by VW) 
1.64 : Fixed Issue 103:	ROEdgeDrivenLayout doesn''t work with Sets of elements. Thanks Daan!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/20/2012 18:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.243';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/23/2012 12:21'!
version165: spec
	<version: '1.65' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.64 : Fixed Issue 103:	ROEdgeDrivenLayout doesn''t work with Sets of elements. Thanks Daan!!
1.65 : Fixed Issue 104:	Odd drag and drop when zooming in'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/23/2012 12:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.244';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 09:39'!
version166: spec
	<version: '1.66' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.65 : Fixed Issue 104:	Odd drag and drop when zooming in
1.66 : Added an explicit stack in the builder. We also introduced ROMondrianFrame to model a stack frame.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 09:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.245';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 11:41'!
version167: spec
	<version: '1.67' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.66 : Added an explicit stack in the builder. We also introduced ROMondrianFrame to model a stack frame.
1.67 : Fixed http://code.google.com/p/moose-technology/issues/detail?id=806'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 11:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.246';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 16:52'!
version168: spec
	<version: '1.68' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.67 : Fixed http://code.google.com/p/moose-technology/issues/detail?id=806
1.68 : Fixed Issue 107:	Have an easy way to select rendering platform'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 16:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.247';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.51'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 17:24'!
version169: spec
	<version: '1.69' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.68 : Fixed Issue 107:	Have an easy way to select rendering platform
1.69 : Loadable version in VisualWorks'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 17:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.248';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.52'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 00:51'!
version16: spec
	<version: '1.6' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.5 : Two popups cannot appear at the same time. http://code.google.com/p/objectprofile/issues/detail?id=48
1.6 : better implementation of parentBehavior. The parent element can now decide whether it has to grow or not. Before it was the children who can decide, which is quite odd.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 00:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.183';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 17:30'!
version170: spec
	<version: '1.70' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.69 : Loadable version in VisualWorks
1.70 : recatogized some methods'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 17:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.248';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.53'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 18:08'!
version171: spec
	<version: '1.71' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.70 : recatogized some methods
1.71 : Added the visual element of the host platform in ROPlatform. This is necessary for the Cairo platform, built upon the VW platform'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 18:08'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.249';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/26/2012 09:36'!
version172: spec
	<version: '1.72' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.71 : Added the visual element of the host platform in ROPlatform. This is necessary for the Cairo platform, built upon the VW platform
1.72 : fixed Issue 109:	Rossal and collections (http://code.google.com/p/moose-technology/issues/detail?id=815). Thanks Tudor Doru Girba!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/26/2012 09:36'.
		spec 
			package: #Roassal with: 'Roassal-TudorGirba.250';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/26/2012 10:38'!
version173: spec
	<version: '1.73' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.72 : fixed Issue 109:	Rossal and collections (http://code.google.com/p/moose-technology/issues/detail?id=815). Thanks Tudor Doru Girba!!
1.73 : minor method categorization'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/26/2012 10:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.251';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/26/2012 11:54'!
version174: spec
	<version: '1.74' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.73 : minor method categorization
1.74 : Fixed Issue 110:	ROForceBasedLayoutTest >> testLayout fails on Windows'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/26/2012 11:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.252';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/27/2012 16:25'!
version175: spec
	<version: '1.75' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.74 : Fixed Issue 110:	ROForceBasedLayoutTest >> testLayout fails on Windows
1.75 : Fixed Issue 111:	Removing the bitmap generation from the core'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/27/2012 16:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.253';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.55'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/27/2012 17:47'!
version176: spec
	<version: '1.76' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.75 : Fixed Issue 111:	Removing the bitmap generation from the core
1.76 : renaming ROAbstractCanvas.canvas into nativeCanvas'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/27/2012 17:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.254';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.56'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/28/2012 22:29'!
version177: spec
	<version: '1.77' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.76 : renaming ROAbstractCanvas.canvas into nativeCanvas
1.77 : Committed a new example tab in the easel. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/28/2012 22:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.255';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/28/2012 22:53'!
version178: spec
	<version: '1.78' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.77 : Committed a new example tab in the easel. 
1.78 : Reorganizing a bit the Mondrian examples.
Fixed Issue 113:	Add an example for the attach point in Roassal
Fixed Issue 112:	Add a legend in the Roassal example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/28/2012 22:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.256';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 08:59'!
version179: spec
	<version: '1.79' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.78 : Reorganizing a bit the Mondrian examples.
Fixed Issue 113:	Add an example for the attach point in Roassal
Fixed Issue 112:	Add a legend in the Roassal example
1.79 : Fixed Issue 114:	HorizontalTreeLayout 
the example have also been updated accordingly '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 08:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.257';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 01:01'!
version17: spec
	<version: '1.7' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.6 : better implementation of parentBehavior. The parent element can now decide whether it has to grow or not. Before it was the children who can decide, which is quite odd.
1.7 : Minor bug fixed in ROAbstractView>>blackHole (basicNew -> new)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 01:01'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.184';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 09:27'!
version180: spec
	<version: '1.80' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.79 : Fixed Issue 114:	HorizontalTreeLayout 
the example have also been updated accordingly 
1.80 : Fixed Issue 115:	adding menu to the background 
For example:
view nodes: (1 to: 50).
view raw @ (ROMenuActivable new 
				item: ''hello'' action: #inspect;
				item: ''world'' action: #inspect).    

'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 09:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.258';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 10:17'!
version181: spec
	<version: '1.81' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.80 : Fixed Issue 115:	adding menu to the background 
For example:
view nodes: (1 to: 50).
view raw @ (ROMenuActivable new 
				item: ''hello'' action: #inspect;
				item: ''world'' action: #inspect).    


1.81 : Fixed Issue 116:	Example>colors>normalizer is not really interesting'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 10:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.259';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 10:26'!
version182: spec
	<version: '1.82' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.81 : Fixed Issue 116:	Example>colors>normalizer is not really interesting
1.82 : Fixed Issue 118:	title of the example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 10:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.259';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.58'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 12:49'!
version183: spec
	<version: '1.83' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.82 : Fixed Issue 118:	title of the example
1.83 : Fixed Issue 120:	Roassal in VW has 3 undeclared variables'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 12:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.260';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.59'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 00:09'!
version184: spec
	<version: '1.84' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.83 : Fixed Issue 120:	Roassal in VW has 3 undeclared variables
1.84 : 
  - Fixed Issue 122:	Vertical Arrow and Reversed Arrow
  - Fixed Issue 121:	OrthoVerticalLine'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 00:09'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.261';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.60'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 00:19'!
version185: spec
	<version: '1.85' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.84 : 
  - Fixed Issue 122:	Vertical Arrow and Reversed Arrow
  - Fixed Issue 121:	OrthoVerticalLine
1.85 : http://code.google.com/p/moose-technology/issues/detail?id=822  
Thanks Doru!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 00:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.267';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.60'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 11:27'!
version186: spec
	<version: '1.86' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.85 : http://code.google.com/p/moose-technology/issues/detail?id=822  
Thanks Doru!!
1.86 : Cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 11:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.267';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.61'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 17:08'!
version187: spec
	<version: '1.87' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.86 : Cleaning
1.87 : minor cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 17:08'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.268';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.61'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/1/2012 16:32'!
version188: spec
	<version: '1.88' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.87 : minor cleaning
1.88 : Fixed Issue Roassal overwriting window borders
 http://code.google.com/p/moose-technology/issues/detail?id=817
http://code.google.com/p/objectprofile/issues/detail?id=123
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/1/2012 16:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.268';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.62'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/2/2012 17:50'!
version189: spec
	<version: '1.89' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.88 : Fixed Issue Roassal overwriting window borders
 http://code.google.com/p/moose-technology/issues/detail?id=817
http://code.google.com/p/objectprofile/issues/detail?id=123

1.89 : Fixed Issue 124:	buttons remains after ROMondiranExample >> chooseLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2012 17:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.268';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 08:50'!
version18: spec
	<version: '1.8' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.7 : Minor bug fixed in ROAbstractView>>blackHole (basicNew -> new)
1.8 : Making invisible edges. Fix Issue #51'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 08:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.185';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/2/2012 18:12'!
version190: spec
	<version: '1.90' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.89 : Fixed Issue 124:	buttons remains after ROMondiranExample >> chooseLayout
1.90 : Issue 125:	Issue 824:	Roassal hover text should disappear when dragging node
http://code.google.com/p/moose-technology/issues/detail?id=824
http://code.google.com/p/objectprofile/issues/detail?id=125'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2012 18:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.269';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/3/2012 11:51'!
version191: spec
	<version: '1.91' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.90 : Issue 125:	Issue 824:	Roassal hover text should disappear when dragging node
http://code.google.com/p/moose-technology/issues/detail?id=824
http://code.google.com/p/objectprofile/issues/detail?id=125
1.91 : Fixed Issue 823:	buttons remains after ROMondrianExample >> chooseLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/3/2012 11:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.270';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/5/2012 11:04'!
version192: spec
	<version: '1.92' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.91 : Fixed Issue 823:	buttons remains after ROMondrianExample >> chooseLayout
1.92 : Added ROOrthoHorizontalLineShape, ROHorizontalArrow, ROReversedHorizontalArrow. Modified examples to show a several combinations of attachPoint method and offset.
Thanks Ben!!!! Really cool!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/5/2012 11:04'.
		spec 
			package: #Roassal with: 'Roassal-BenComan.271';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/5/2012 12:06'!
version193: spec
	<version: '1.93' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.92 : Added ROOrthoHorizontalLineShape, ROHorizontalArrow, ROReversedHorizontalArrow. Modified examples to show a several combinations of attachPoint method and offset.
Thanks Ben!!!! Really cool!!
1.93 : colorFor: for labels'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/5/2012 12:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.272';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 09:59'!
version194: spec
	<version: '1.94' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.93 : colorFor: for labels
1.94 : 
	Fixed Issue 129:	Strange popupView in Roassal
	http://code.google.com/p/moose-technology/issues/detail?id=827'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 09:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.273';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 10:15'!
version195: spec
	<version: '1.95' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.94 : 
	Fixed Issue 129:	Strange popupView in Roassal
	http://code.google.com/p/moose-technology/issues/detail?id=827
1.95 : Fixed Issue 130:	ROBeginingAnimation>>isOver'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 10:15'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.274';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.64'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 11:26'!
version196: spec
	<version: '1.96' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.95 : Fixed Issue 130:	ROBeginingAnimation>>isOver
1.96 : commented addLast: Thanks Ben for the suggestion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 11:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.275';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.64'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 11:51'!
version197: spec
	<version: '1.97' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.96 : commented addLast: Thanks Ben for the suggestion
1.97 : Issue 131:	ROMorph>>mouseOver:
	http://code.google.com/p/moose-technology/issues/detail?id=828'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 11:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.276';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.65'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/20/2012 08:59'!
version198: spec
	<version: '1.98' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.97 : Issue 131:	ROMorph>>mouseOver:
	http://code.google.com/p/moose-technology/issues/detail?id=828
1.98 : 
	Fixed Issue 132:	ROElement, ROEdge
	Fixed Issue 133:	ROShape>>removeShape:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/20/2012 08:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.277';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.65'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/20/2012 11:13'!
version199: spec
	<version: '1.99' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.98 : 
	Fixed Issue 132:	ROElement, ROEdge
	Fixed Issue 133:	ROShape>>removeShape:
1.99 : Fixed Issue 136:	Roassal hover popup on edges
	http://code.google.com/p/moose-technology/issues/detail?id=826'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/20/2012 11:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.278';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.65'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 14:00'!
version19: spec
	<version: '1.9' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.8 : Making invisible edges. Fix Issue #51
1.9 : Added a sortElementsWith: on ROAbstractView to reorder the nodes. Added a doPost: on ROLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 14:00'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.186';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !
